@@ -63,6 +63,12 @@ class TestForms(unittest.TestCase):
 
     def test_form_select(self):
         form = self.callFUT()
+
+        self.assertEqual(form['select'].options, [
+            ('value1', False, 'Value 1'),
+            ('value2', True, 'Value 2'),
+            ('value3', False, 'Value 3')
+        ])
         form.select('select', 'value1')
 
         self.assertEqual(
@@ -134,6 +140,11 @@ class TestForms(unittest.TestCase):
                           form.submit, "action", value="activate",
                           index=0)
 
+    def test_outer_inputs(self):
+        form = self.callFUT(formid='outer_inputs_form')
+        self.assertEqual(('foo', 'bar', 'button'), tuple(form.fields))
+        # check that identical input is not considered belonging to this form
+        self.assertTrue(all(len(itm) == 1 for itm in form.fields.values()))
 
 class TestResponseFormAttribute(unittest.TestCase):
 
@@ -285,26 +296,33 @@ class TestInput(unittest.TestCase):
 class TestFormLint(unittest.TestCase):
 
     def test_form_lint(self):
-        form = webtest.Form(None, '''<form>
+        def _build_response(html):
+            return webtest.TestResponse('<body>{}</body>'.format(html))
+
+        html = '''<form>
         <input type="text" name="field"/>
-        </form>''')
+        </form>'''
+        form = webtest.Form(_build_response(html), html)
         self.assertRaises(AttributeError, form.lint)
 
-        form = webtest.Form(None, '''<form>
+        html = '''<form>
         <input type="text" id="myfield" name="field"/>
-        </form>''')
+        </form>'''
+        form = webtest.Form(_build_response(html), html)
         self.assertRaises(AttributeError, form.lint)
 
-        form = webtest.Form(None, '''<form>
+        html = '''<form>
         <label for="myfield">my field</label>
         <input type="text" id="myfield" name="field"/>
-        </form>''')
+        </form>'''
+        form = webtest.Form(_build_response(html), html)
         form.lint()
 
-        form = webtest.Form(None, '''<form>
+        html = '''<form>
         <label class="field" for="myfield" role="r">my field</label>
         <input type="text" id="myfield" name="field"/>
-        </form>''')
+        </form>'''
+        form = webtest.Form(_build_response(html), html)
         form.lint()
 
 
